# Electioncoefs.R
#
# Election counter coefficients for the three models
#
# Patrick T. Brandt
#
# April 10, 2006
#
library(MSBVAR)
source("~/devel-stable/MSBVAR/R/hidden.R")


"mcmc.structural.szbvar" <- function(varobj, A0.posterior)
  {
    m<-dim(varobj$ar.coefs)[1]  # Capture the number of variablesbcoefs <- varobj$Bhat
    p<-dim(varobj$ar.coefs)[3]    # Capture the number of lags

    ncoef <- dim(varobj$B.posterior)[1]
    n0 <- varobj$n0
    n0cum <- c(0,cumsum(n0))
    N2 <- A0.posterior$N2

  # Get the covar for the coefficients
    XXinv <- chol(solve(varobj$Hpinv.posterior[[1]]))

  # storage for the sampled coefficients.
    B.sample <- matrix(0, nrow=N2, ncol=ncoef*m)

  # Loop for the impulse responses
    for(i in 1:N2)
    {
      # Set up the A0 for this iteration
        A0 <- A0.get(A0.posterior$A0.posterior, i)
        A0inv <- solve(A0)

        bj <- a2b(A0, varobj$Ui)

        F.draw <- matrix(0, ncoef, m)

        for(j in 1:m)
        { btmp <- bj[(n0cum[j]+1):(n0cum[(j+1)])]
          F.draw[,j] <- varobj$P.posterior[[j]]%*%(btmp)
        }

        F.draw <- F.draw + XXinv%*%matrix(rnorm(m*ncoef), ncoef, m)
        B.draw <- F.draw%*%(A0inv)

        B.sample[i,] <- matrix(B.draw, 1, ncoef*m)
        if (i%%1000==0)
        { cat("Monte Carlo Iteration = ", i, "\n"); }
    }

    # output / return
    output <- list(B.sample=B.sample)
    class(output) <- c("mcmc.bsvar.posterior")
    return(output)

  }


# Load the A(0) matrices for each of the models
load("Model1.Rdata")
rm(Model1.impulses)
gc()

load("Model2.Rdata")
rm(Model2.impulses)
gc()

load("Model3.Rdata")
rm(Model3.impulses)
gc()


# Now draw all of the regression coefficients --- these are the
# reduced form coefficients

# Set in the indices for the election coefficients
elec.indices <- c(1:11)*68

set.seed(4687)

Model1.coefs <- mcmc.structural.szbvar(model1,
                                       Model1.A0.posterior.obj)

Model2.coefs <- mcmc.structural.szbvar(model2,
                                       Model2.A0.posterior.obj)

Model3.coefs <- mcmc.structural.szbvar(model3,
                                       Model3.A0.posterior.obj)


# Subset out the election coefficients for each of the output
Model1.elec <- Model1.coefs$B.sample[,elec.indices]
Model2.elec <- Model2.coefs$B.sample[,elec.indices]
Model3.elec <- Model3.coefs$B.sample[,elec.indices]


## # Plot the densities.... same styling as in the IRFs
## jpeg(file="Electioncoefs.jpeg", width=400, height=500, bg="white",
##      quality=100)

## par(mfcol=c(6,2), mai=c(0.3,0.6,0.25,0.25))
## for (i in 1:11)
## { density1 <- density(Model1.elec[,i])
##   density2 <- density(Model2.elec[,i])
##   density3 <- density(Model3.elec[,i])

##   rangex <- range(density1$x, density2$x, density3$x)
##   rangey <- range(density1$y, density2$y, density3$y)

##   plot(density1, ylim=rangey, xlim=rangex, main=colnames(Y)[i],
##        lty=1, ylab="")
##   lines(density2, lty=2)
##   lines(density3, lty=3)
##   abline(v=0)

## }
## dev.off()

pdf(file="Electioncoefs.pdf", width=6, height=8)

par(mfcol=c(6,2), mai=c(0.3,0.6,0.25,0.25))
for (i in 1:11)
{ density1 <- density(Model1.elec[,i])
  density2 <- density(Model2.elec[,i])
  density3 <- density(Model3.elec[,i])

  rangex <- range(density1$x, density2$x, density3$x)
  rangey <- range(density1$y, density2$y, density3$y)

  plot(density1, ylim=rangey, xlim=rangex, main=colnames(Y)[i],
       lty=1, ylab="")
  lines(density2, lty=2)
  lines(density3, lty=3)
  abline(v=0)

}
dev.off()

library(coda)
HPDinterval(mcmc(Model1.elec), prob=0.95)
HPDinterval(mcmc(Model1.elec), prob=0.68)
HPDinterval(mcmc(Model2.elec), prob=0.95)
HPDinterval(mcmc(Model2.elec), prob=0.68)
HPDinterval(mcmc(Model3.elec), prob=0.95)
HPDinterval(mcmc(Model3.elec), prob=0.68)


q(save="no")
