# Model1-newcounter.R
#
# Start date: October 2005
#
# This version: November 5, 2006
#

library(MSBVAR)
library(coda)

# Load the data and A0 structure
load("SFB_models_data_and_structures.RData")

set.seed(100)

model1 <- szbsvar(Y, p, z=X1,
                  lambda0=lambda0,
                  lambda1=lambda1,
                  lambda3=lambda3,
                  lambda4=lambda4,
                  lambda5=lambda5,
                  mu5=mu5,
                  mu6=mu6,
                  ident = Model1.A0,
                  qm)

# Calculate and print model fit

Model1.A0.posterior.obj <- gibbs.A0(model1,
                                    normalization="DistanceMLA",
                                    N1=N1, N2=N2, thin=thin)
# Check convergence

SFB.model1.A0 <- A02mcmc(Model1.A0.posterior.obj)

print(geweke.diag(SFB.model1.A0))
print(summary(SFB.model1.A0))

# Generate some posterior fit measures
model1.fit <- posterior.fit(model1, Model1.A0.posterior.obj)

print(model1.fit)

# Sample and plot the impulse responses

Model1.impulses <- mc.irf(model1, nsteps=12,
                          A0.posterior=Model1.A0.posterior.obj)

pdf(file="Model1_IRF_newcounter.pdf", width=8, height=8)

plot(100*Model1.impulses, method="Percentile",
     varnames=colnames(Y))

dev.off()

# Save results and quit
save.image(file="Model1-newcounter.RData", compress=T)

q(save="no")


