# Model2.R
#
# Start date: October 2005
#
# This version: March 30, 2006
#

library(MSBVAR)
library(coda)

# Load the data and A0 structure
load("SFB_models_data_and_structures.RData")

set.seed(100)

model2 <- szbsvar(Y, p, z=X,
                  lambda0=lambda0,
                  lambda1=lambda1,
                  lambda3=lambda3,
                  lambda4=lambda4,
                  lambda5=lambda5,
                  mu5=mu5,
                  mu6=mu6,
                  ident = Model2.A0,
                  qm)

# Calculate and print model fit

Model2.A0.posterior.obj <- gibbs.A0(model2,
                                    normalization="DistanceMLA",
                                    N1=N1, N2=N2, thin=thin)

# Check convergence

SFB.model2.A0 <- A02mcmc(Model2.A0.posterior.obj)

pdf(file="Model2TraceDensity.pdf")
plot(SFB.model2.A0)
dev.off()

print(geweke.diag(SFB.model2.A0))
print(summary(SFB.model2.A0))


# Generate some posterior fit measures
model2.fit <- posterior.fit(model2, Model2.A0.posterior.obj)

print(model2.fit)

# Sample and plot the impulse responses

Model2.impulses <- mc.irf(model2, nsteps=12, A0.posterior=Model2.A0.posterior.obj)

pdf(file="Model2_IRF.pdf", width=8, height=8)

plot(100*Model2.impulses, varnames=colnames(Y))
dev.off()

save.image(file="Model2.RData", compress=T)

q(save="no")


