# Model3-newcounter.R
#
# Start date: October 2005
#
# This version: November 5, 2006
#

library(MSBVAR)
library(coda)

# Load the data and A0 structure
load("SFB_models_data_and_structures.RData")

set.seed(100)

model3 <- szbsvar(Y, p, z=X1,
                  lambda0=lambda0,
                  lambda1=lambda1,
                  lambda3=lambda3,
                  lambda4=lambda4,
                  lambda5=lambda5,
                  mu5=mu5,
                  mu6=mu6,
                  ident = Model3.A0,
                  qm)

# Calculate and print model fit

Model3.A0.posterior.obj <- gibbs.A0(model3,
                                    normalization="DistanceMLA",
                                    N1=N1, N2=N2, thin=thin)
# Check convergence

SFB.model3.A0 <- A02mcmc(Model3.A0.posterior.obj)

print(geweke.diag(SFB.model3.A0))
print(summary(SFB.model3.A0))

# Generate some posterior fit measures
model3.fit <- posterior.fit(model3, Model3.A0.posterior.obj)

print(model3.fit)

# Sample and plot the impulse responses

Model3.impulses <- mc.irf(model3, nsteps=12,
                          A0.posterior=Model3.A0.posterior.obj)

pdf(file="Model3_IRF_newcounter.pdf", width=8, height=8)

plot(100*Model3.impulses, method="Percentile",
     varnames=colnames(Y))
dev.off()

# Save results and quit
save.image(file="Model3-newcounter.RData", compress=T)

q(save="no")
