# Sensitivity.R

# 2006-11-01 : Initial version

library(MSBVAR)
library(coda)

# Load the data and A0 structures
load("SFB_models_data_and_structures.RData")

set.seed(100)

# Combination of the hyperparameters to be evaluated
lambda0 <- seq(0.6, 0.8, by=0.1)
lambda1 <- seq(0.1, 0.2, by=0.05)
lambda3 <- 1:2
lambda4 <- lambda1
lambda5 <- lambda4/2
mu6 <- mu5 <- seq(0, 7, by=1)



# New version of this -- optimized for speed and more values of the
# hyperparameters

SZ.prior.evaluation <- function (Y, p, lambda0, lambda1, lambda3, lambda4, lambda5,
                                 mu5, mu6, z = NULL, nu = ncol(Y) + 1, qm, prior = 0, nstep,
                                 y.future)
{
    combos <- length(lambda0) * length(lambda1) * length(lambda3) *
        length(lambda4) * length(lambda5) * length(mu5) * length(mu6)

    results <- matrix(0, combos, 11)

    results[,1:7] <- as.matrix(expand.grid(lambda0=lambda0, lambda1=lambda1,
                                           lambda3=lambda3, lambda4=lambda4,
                                           lambda5=lambda5, mu5=mu5, mu6=mu6))

    for (i in 1:nrow(results))
    {
        fit <- szbvar(Y, p, z, lambda0=results[i,1],
                      lambda1=results[i,2],
                      lambda3=results[i,3], lambda4=results[i,4],
                      lambda5 = results[i,5],
                      mu5 = results[i,6], mu6 = results[i,7], nu =
                      ncol(Y)+1, qm = qm, prior = prior,
                      posterior.fit = T)

        forecast <- forecast.VAR(fit, nstep)
        eval.forecasts <- cf.forecasts(forecast[(nrow(forecast) -
                                                 nstep + 1):nrow(forecast), ], y.future)

        tmp <- c(eval.forecasts[1], eval.forecasts[2], fit$marg.llf[1], fit$marg.post[1])

        results[i, 8:11] <- tmp

        if(i%%100==T) { cat("Finished model", i, "of", nrow(results),"\n") }

    }
    colnames(results) <- c("lambda0", "lambda1", "lambda3", "lambda4",
                           "lambda5", "mu5", "mu6", "RMSE", "MAE", "LLF", "logMDD")
    return(results)
}


results <- SZ.prior.evaluation(window(Y, end=c(1996,4)), p, lambda0,
                               lambda1, lambda3, lambda4, lambda5,
                               mu5, mu6, z = NULL, nu = ncol(Y) + 1, 12, prior = 0, nstep=12,
                               y.future=window(Y, start=c(1996,5)))


save.image("SensitivityResults.RData")

# Plotting of the results

# Note that lambda0 = 0.6 is the unequivocal choice on the logMDD criteria

results <- as.data.frame(results)

pdf(file="logMDD1.pdf", width=5, height=5)

print(xyplot(logMDD ~ lambda1 | lambda3, data=results[results$lambda0==0.6,],
   panel=function(x,y) {panel.xyplot(x,y); panel.lmline(x,y)}))
dev.off()

pdf(file="logMDD2.pdf")

print(xyplot(logMDD ~ mu5 | mu6, data=results[results$lambda0==0.6,],
   panel=function(x,y) {panel.xyplot(x,y);
   panel.lmline(x,y)}))

dev.off()

pdf(file="logMDD3.pdf", width=5, height=5)

print(xyplot(logMDD ~ lambda4 | lambda5, data=results,
   panel=function(x,y) {panel.xyplot(x,y);
   panel.lmline(x,y)}))
dev.off()



q(save="no")

