# setupSFB.R
#
# Setup file for running Sattler-Freeman-Brandt Open economy /
# politics models
#
# Patrick Brandt
#
# March 30, 2006
#
library(MSBVAR)

# Read data
SFB <- read.csv("UK.csv",sep = ",")
attach(SFB)

# Define object for endogenous variables

Y <- ts(cbind(log(usxr), 0.01*ibir, 0.01*usibir, log(cpi), log(iip),
              log(uscpi), log(usiip), 0.01*se, 0.01*pe, 0.01*pm,
              0.01*vi), start=c(1981,11), frequency=12, names =
        c("XR", "IR", "USIR", "CPI", "IIP", "USCPI", "USIIP", "SE",
          "PE", "PM", "VI"))

X <- ts(cbind(counter), start=c(1981,11), frequency=12, names = c("ELECTION"))
X1 <- ts(cbind(counter1, counter2, counter3), start=c(1981,11),
         frequency=12, names = c("ELECTION1", "ELECTION2",
                       "ELECTION3"))

detach(SFB)

# Define A0s

# Model 1
m <- ncol(Y)
Model1.A0 <- matrix(0, m, m)
diag(Model1.A0) <- 1
colnames(Model1.A0) <- c("XR", "IR", "USIR", "CPI", "IIP", "USCPI", "USIIP", "SE", "PE", "PM", "VI")
rownames(Model1.A0) <- colnames(Model1.A0)

Model1.A0[2:11,1] <- 1
Model1.A0[1:3,2] <- 1
Model1.A0[1,3] <- 1
Model1.A0[4:7,4] <- 1
Model1.A0[5:7,5] <- 1
Model1.A0[7,6] <- 1
Model1.A0[8,9] <- 1
Model1.A0[8:9,10] <- 1
Model1.A0[8:10,11] <-1

# Model 2
Model2.A0 <- matrix(0, m, m)
diag(Model2.A0) <- 1
colnames(Model2.A0) <- c("XR", "IR", "USIR", "CPI", "IIP", "USCPI", "USIIP", "SE", "PE", "PM", "VI")
rownames(Model2.A0) <- colnames(Model2.A0)

Model2.A0[2:11,1] <- 1
Model2.A0[1:3,2] <- 1
Model2.A0[1,3] <- 1
Model2.A0[4:7,4] <- 1
Model2.A0[5:7,5] <- 1
Model2.A0[7,6] <- 1
Model2.A0[8,9] <- 1
Model2.A0[8:9,10] <- 1
Model2.A0[8:10,11] <-1
Model2.A0[8:11,2] <- 1

# Model 3 A0
Model3.A0 <- matrix(0, m, m)
diag(Model3.A0) <- 1
colnames(Model3.A0) <- c("XR", "IR", "USIR", "CPI", "IIP", "USCPI", "USIIP", "SE", "PE", "PM", "VI")
rownames(Model3.A0) <- colnames(Model3.A0)

Model3.A0[2:11,1] <- 1
Model3.A0[1:3,2] <- 1
Model3.A0[1,3] <- 1
Model3.A0[4:7,4] <- 1
Model3.A0[5:7,5] <- 1
Model3.A0[7,6] <- 1
Model3.A0[8,9] <- 1
Model3.A0[8:9,10] <- 1
Model3.A0[8:10,11] <-1
Model3.A0[8:11,2] <- 1
Model3.A0[2,8:11] <- 1


# Set parameters / hyperparameters for the models
p <- 6
qm <- 12
N1 <- 5000
N2 <- 50000
thin <- 1

lambda0 <- 0.6
lambda1 <- 0.1
lambda3 <- 1
lambda4 <- 0.1
lambda5 <- 0.05
mu5 <- 5
mu6 <- 5

save.image("SFB_models_data_and_structures.RData")

q(save="no")
